Coverage for /home/ken/.local/lib/python3.6/site-packages/avendesora/__init__.py: 85%

# Coverage for /home/ken/.local/lib/python3.6/site-packages/avendesora/__init__.py : 85%

## 13 statements 11 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 | from .charsets import ( exclude, LOWERCASE, UPPERCASE, LETTERS, DIGITS, ALPHANUMERIC, HEXDIGITS, PUNCTUATION, SYMBOLS, WHITESPACE, PRINTABLE, DISTINGUISHABLE ) from .account import Account, StealthAccount from .secrets import ( Password, Passphrase, PIN, Question, MixedPassword, PasswordRecipe, BirthDate, ) from .obscure import Hidden, GPG try: from .obscure import Scrypt except ImportError: pass from .recognize import ( RecognizeAll, RecognizeAny, RecognizeTitle, RecognizeURL, RecognizeCWD, RecognizeHost, RecognizeUser, RecognizeEnvVar ) from .generator import PasswordGenerator from inform import Error as PasswordError __version__ = '0.15.6' __released__ = '2016-12-16'